@@ -13,7 +13,7 @@
  * building a dispatch function.
  * ----------------------------------------------------------------------------- */
 
-char cvsroot_overload_cxx[] = "$Id: overload.cxx 12474 2011-02-18 21:25:42Z wsfulton $";
+char cvsroot_overload_cxx[] = "$Id: overload.cxx 12108 2010-06-10 01:13:31Z ianlancetaylor $";
 
 #include "swigmod.h"
 
@@ -386,11 +386,16 @@ String *Swig_overload_dispatch_cast(Node *n, const_String_or_char_ptr fmt, int *
     int num_arguments = emit_num_arguments(pi);
     if (num_arguments > *maxargs)
       *maxargs = num_arguments;
+    int varargs = emit_isvarargs(pi);
 
-    if (num_required == num_arguments) {
-      Printf(f, "if (%s == %d) {\n", argc_template_string, num_required);
+    if (!varargs) {
+      if (num_required == num_arguments) {
+	Printf(f, "if (%s == %d) {\n", argc_template_string, num_required);
+      } else {
+	Printf(f, "if ((%s >= %d) && (%s <= %d)) {\n", argc_template_string, num_required, argc_template_string, num_arguments);
+      }
     } else {
-      Printf(f, "if ((%s >= %d) && (%s <= %d)) {\n", argc_template_string, num_required, argc_template_string, num_arguments);
+      Printf(f, "if (%s >= %d) {\n", argc_template_string, num_required);
     }
     Printf(f, "SWIG_TypeRank _ranki = 0;\n");
     Printf(f, "SWIG_TypeRank _rankm = 0;\n");
@@ -560,11 +565,16 @@ String *Swig_overload_dispatch_fast(Node *n, const_String_or_char_ptr fmt, int *
     int num_arguments = emit_num_arguments(pi);
     if (num_arguments > *maxargs)
       *maxargs = num_arguments;
+    int varargs = emit_isvarargs(pi);
 
-    if (num_required == num_arguments) {
-      Printf(f, "if (%s == %d) {\n", argc_template_string, num_required);
+    if (!varargs) {
+      if (num_required == num_arguments) {
+	Printf(f, "if (%s == %d) {\n", argc_template_string, num_required);
+      } else {
+	Printf(f, "if ((%s >= %d) && (%s <= %d)) {\n", argc_template_string, num_required, argc_template_string, num_arguments);
+      }
     } else {
-      Printf(f, "if ((%s >= %d) && (%s <= %d)) {\n", argc_template_string, num_required, argc_template_string, num_arguments);
+      Printf(f, "if (%s >= %d) {\n", argc_template_string, num_required);
     }
 
     /* create a list with the wrappers that collide with the
@@ -722,11 +732,16 @@ String *Swig_overload_dispatch(Node *n, const_String_or_char_ptr fmt, int *maxar
     }
     if (num_arguments > *maxargs)
       *maxargs = num_arguments;
+    int varargs = emit_isvarargs(pi);
 
-    if (num_required == num_arguments) {
-      Printf(f, "if (%s == %d) {\n", argc_template_string, num_required);
+    if (!varargs) {
+      if (num_required == num_arguments) {
+	Printf(f, "if (%s == %d) {\n", argc_template_string, num_required);
+      } else {
+	Printf(f, "if ((%s >= %d) && (%s <= %d)) {\n", argc_template_string, num_required, argc_template_string, num_arguments);
+      }
     } else {
-      Printf(f, "if ((%s >= %d) && (%s <= %d)) {\n", argc_template_string, num_required, argc_template_string, num_arguments);
+      Printf(f, "if (%s >= %d) {\n", argc_template_string, num_required);
     }
 
     if (num_arguments) {
