@@ -17,7 +17,7 @@
  * - Lines beginning with %# are stripped down to #... and passed through.
  * ----------------------------------------------------------------------------- */
 
-char cvsroot_cpp_c[] = "$Id: cpp.c 12467 2011-02-17 21:54:13Z wsfulton $";
+char cvsroot_cpp_c[] = "$Id: cpp.c 12215 2010-09-11 11:02:18Z wsfulton $";
 
 #include "swig.h"
 #include "preprocessor.h"
@@ -33,7 +33,6 @@ static Hash *included_files = 0;
 static List *dependencies = 0;
 static Scanner *id_scan = 0;
 static int error_as_warning = 0;	/* Understand the cpp #error directive as a special #warning */
-static int expand_defined_operator = 0;
 static int macro_level = 0;
 static int macro_start_line = 0;
 static const String * macro_start_file = 0;
@@ -152,9 +151,6 @@ static String *kpp_dextern = 0;
 static String *kpp_LINE = 0;
 static String *kpp_FILE = 0;
 
-static String *kpp_hash_if = 0;
-static String *kpp_hash_elif = 0;
-
 void Preprocessor_init(void) {
   Hash *s;
 
@@ -191,9 +187,6 @@ void Preprocessor_init(void) {
   kpp_LINE = NewString("__LINE__");
   kpp_FILE = NewString("__FILE__");
 
-  kpp_hash_if = NewString("#if");
-  kpp_hash_elif = NewString("#elif");
-
   cpp = NewHash();
   s = NewHash();
   Setattr(cpp, kpp_symbols, s);
@@ -235,12 +228,9 @@ void Preprocessor_delete(void) {
   Delete(kpp_ddefine);
   Delete(kpp_dline);
 
+
   Delete(kpp_LINE);
   Delete(kpp_FILE);
-
-  Delete(kpp_hash_if);
-  Delete(kpp_hash_elif);
-
   Delete(cpp);
   Delete(included_files);
   Preprocessor_expr_delete();
@@ -643,7 +633,7 @@ unterm:
 }
 
 /* -----------------------------------------------------------------------------
- * DOH *get_filename()
+ * DOH *get_filename(DOH *str)
  *
  * Read a filename from str.   A filename can be enclosed in quotes, angle brackets,
  * or bare.
@@ -955,6 +945,22 @@ static String *expand_macro(String *name, List *args, String *line_file) {
   return e;
 }
 
+/* -----------------------------------------------------------------------------
+ * evaluate_args()
+ *
+ * Evaluate the arguments of a macro 
+ * ----------------------------------------------------------------------------- */
+
+List *evaluate_args(List *x) {
+  Iterator i;
+  List *nl = NewList();
+
+  for (i = First(x); i.item; i = Next(i)) {
+    Append(nl, Preprocessor_replace(i.item));
+  }
+  return nl;
+}
+
 /* -----------------------------------------------------------------------------
  * DOH *Preprocessor_replace(DOH *s)
  *
@@ -969,6 +975,7 @@ static String *expand_macro(String *name, List *args, String *line_file) {
 static DOH *Preprocessor_replace(DOH *s) {
   DOH *ns, *symbols, *m;
   int c, i, state = 0;
+
   String *id = NewStringEmpty();
 
   assert(cpp);
@@ -982,18 +989,10 @@ static DOH *Preprocessor_replace(DOH *s) {
   while ((c = Getc(s)) != EOF) {
     switch (state) {
     case 0:
-      if (isidentifier(c)) {
+      if (isidentifier(c) || (c == '%')) {
 	Clear(id);
 	Putc(c, id);
-	state = 4;
-      } else if (c == '%') {
-	Clear(id);
-	Putc(c, id);
-	state = 2;
-      } else if (c == '#') {
-	Clear(id);
-	Putc(c, id);
-	state = 4;
+	state = 1;
       } else if (c == '\"') {
 	Putc(c, ns);
 	skip_tochar(s, '\"', ns);
@@ -1003,87 +1002,62 @@ static DOH *Preprocessor_replace(DOH *s) {
       } else if (c == '/') {
 	Putc(c, ns);
 	state = 10;
-      } else if (c == '\\') {
-	Putc(c, ns);
-	c = Getc(s);
-	if (c == '\n') {
-	  Putc(c, ns);
-	} else {
-	  Ungetc(c, s);
-	}
-      } else if (c == '\n') {
-	Putc(c, ns);
-	expand_defined_operator = 0;
       } else {
 	Putc(c, ns);
       }
       break;
-    case 2:
-      /* Found '%#' */
-      if (c == '#') {
-	Putc(c, id);
-	state = 4;
-      } else {
-	Ungetc(c, s);
-	state = 4;
-      }
-      break;
-    case 4:			/* An identifier */
+    case 1:			/* An identifier */
       if (isidchar(c)) {
 	Putc(c, id);
-	state = 4;
+	state = 1;
       } else {
 	/* We found the end of a valid identifier */
 	Ungetc(c, s);
-	/* See if this is the special "defined" operator */
-       	if (Equal(kpp_defined, id)) {
-	  if (expand_defined_operator) {
-	    int lenargs = 0;
-	    DOH *args = 0;
-	    /* See whether or not a parenthesis has been used */
-	    skip_whitespace(s, 0);
-	    c = Getc(s);
-	    if (c == '(') {
-	      Ungetc(c, s);
-	      args = find_args(s, 0, kpp_defined);
-	    } else if (isidchar(c)) {
-	      DOH *arg = NewStringEmpty();
-	      args = NewList();
-	      Putc(c, arg);
-	      while (((c = Getc(s)) != EOF)) {
-		if (!isidchar(c)) {
-		  Ungetc(c, s);
-		  break;
-		}
-		Putc(c, arg);
-	      }
-	      if (Len(arg))
-		Append(args, arg);
-	      Delete(arg);
-	    } else {
-	      Seek(s, -1, SEEK_CUR);
-	    }
-	    lenargs = Len(args);
-	    if ((!args) || (!lenargs)) {
-	      /* This is not a defined() operator. */
-	      Append(ns, id);
-	      state = 0;
-	      break;
-	    }
-	    for (i = 0; i < lenargs; i++) {
-	      DOH *o = Getitem(args, i);
-	      if (!Getattr(symbols, o)) {
+	/* See if this is the special "defined" macro */
+	if (Equal(kpp_defined, id)) {
+	  int lenargs = 0;
+	  DOH *args = 0;
+	  /* See whether or not a parenthesis has been used */
+	  skip_whitespace(s, 0);
+	  c = Getc(s);
+	  if (c == '(') {
+	    Ungetc(c, s);
+	    args = find_args(s, 0, kpp_defined);
+	  } else if (isidchar(c)) {
+	    DOH *arg = NewStringEmpty();
+	    args = NewList();
+	    Putc(c, arg);
+	    while (((c = Getc(s)) != EOF)) {
+	      if (!isidchar(c)) {
+		Ungetc(c, s);
 		break;
 	      }
+	      Putc(c, arg);
 	    }
-	    if (i < lenargs)
-	      Putc('0', ns);
-	    else
-	      Putc('1', ns);
-	    Delete(args);
+	    if (Len(arg))
+	      Append(args, arg);
+	    Delete(arg);
 	  } else {
-	    Append(ns, id);
+	    Seek(s, -1, SEEK_CUR);
 	  }
+	  lenargs = Len(args);
+	  if ((!args) || (!lenargs)) {
+	    /* This is not a defined() macro. */
+	    Append(ns, id);
+	    state = 0;
+	    break;
+	  }
+	  for (i = 0; i < lenargs; i++) {
+	    DOH *o = Getitem(args, i);
+	    if (!Getattr(symbols, o)) {
+	      break;
+	    }
+	  }
+	  if (i < lenargs)
+	    Putc('0', ns);
+	  else
+	    Putc('1', ns);
+	  Delete(args);
 	  state = 0;
 	  break;
 	} else if (Equal(kpp_LINE, id)) {
@@ -1097,17 +1071,6 @@ static DOH *Preprocessor_replace(DOH *s) {
 	  Delete(fn);
 	  state = 0;
 	  break;
-	} else if (Equal(kpp_hash_if, id) || Equal(kpp_hash_elif, id)) {
-	  expand_defined_operator = 1;
-	  Append(ns, id);
-	  /*
-	} else if (Equal("%#if", id) || Equal("%#ifdef", id)) {
-	  Swig_warning(998, Getfile(s), Getline(s), "Found: %s preprocessor directive.\n", id);
-	  Append(ns, id);
-	} else if (Equal("#ifdef", id) || Equal("#ifndef", id)) {
-	  Swig_warning(998, Getfile(s), Getline(s), "The %s preprocessor directive does not work in macros, try #if instead.\n", id);
-	  Append(ns, id);
-	  */
 	} else if ((m = Getattr(symbols, id))) {
 	  /* See if the macro is defined in the preprocessor symbol table */
 	  DOH *args = 0;
@@ -1155,15 +1118,11 @@ static DOH *Preprocessor_replace(DOH *s) {
       Putc(c, ns);
       break;
     case 11:
-      /* in C++ comment */
       Putc(c, ns);
-      if (c == '\n') {
-	expand_defined_operator = 0;
+      if (c == '\n')
 	state = 0;
-      }
       break;
     case 12:
-      /* in C comment */
       Putc(c, ns);
       if (c == '*')
 	state = 13;
@@ -1182,8 +1141,8 @@ static DOH *Preprocessor_replace(DOH *s) {
   }
 
   /* Identifier at the end */
-  if (state == 2 || state == 4) {
-    /* See if this is the special "defined" operator */
+  if (state == 1) {
+    /* See if this is the special "defined" macro */
     if (Equal(kpp_defined, id)) {
       Swig_error(Getfile(s), Getline(s), "No arguments given to defined()\n");
     } else if (Equal(kpp_LINE, id)) {
@@ -1552,14 +1511,9 @@ String *Preprocessor_parse(String *s) {
 	level++;
 	if (allow) {
 	  start_level = level;
-	  if (Len(value) > 0) {
-	    /* See if the identifier is in the hash table */
-	    if (!Getattr(symbols, value))
-	      allow = 0;
-	  } else {
-	    Swig_error(Getfile(s), Getline(id), "Missing identifier for #ifdef.\n");
+	  /* See if the identifier is in the hash table */
+	  if (!Getattr(symbols, value))
 	    allow = 0;
-	  }
 	  mask = 1;
 	}
       } else if (Equal(id, kpp_ifndef)) {
@@ -1567,14 +1521,9 @@ String *Preprocessor_parse(String *s) {
 	level++;
 	if (allow) {
 	  start_level = level;
-	  if (Len(value) > 0) {
-	    /* See if the identifier is in the hash table */
-	    if (Getattr(symbols, value))
-	      allow = 0;
-	  } else {
-	    Swig_error(Getfile(s), Getline(id), "Missing identifier for #ifndef.\n");
+	  /* See if the identifier is in the hash table */
+	  if (Getattr(symbols, value))
 	    allow = 0;
-	  }
 	  mask = 1;
 	}
       } else if (Equal(id, kpp_else)) {
@@ -1582,8 +1531,6 @@ String *Preprocessor_parse(String *s) {
 	  Swig_error(Getfile(s), Getline(id), "Misplaced #else.\n");
 	} else {
 	  cond_lines[level - 1] = Getline(id);
-	  if (Len(value) != 0)
-	    Swig_warning(WARN_PP_UNEXPECTED_TOKENS, Getfile(s), Getline(id), "Unexpected tokens after #else directive.\n");
 	  if (allow) {
 	    allow = 0;
 	    mask = 0;
@@ -1598,8 +1545,6 @@ String *Preprocessor_parse(String *s) {
 	  level = 0;
 	} else {
 	  if (level < start_level) {
-	    if (Len(value) != 0)
-	      Swig_warning(WARN_PP_UNEXPECTED_TOKENS, Getfile(s), Getline(id), "Unexpected tokens after #endif directive.\n");
 	    allow = 1;
 	    start_level--;
 	  }
@@ -1609,30 +1554,22 @@ String *Preprocessor_parse(String *s) {
 	level++;
 	if (allow) {
 	  int val;
-	  String *sval;
-	  expand_defined_operator = 1;
-	  sval = Preprocessor_replace(value);
+	  String *sval = Preprocessor_replace(value);
 	  start_level = level;
 	  Seek(sval, 0, SEEK_SET);
 	  /*      Printf(stdout,"Evaluating '%s'\n", sval); */
-	  if (Len(sval) > 0) {
-	    val = Preprocessor_expr(sval, &e);
-	    if (e) {
-	      char *msg = Preprocessor_expr_error();
-	      Seek(value, 0, SEEK_SET);
-	      Swig_warning(WARN_PP_EVALUATION, Getfile(value), Getline(value), "Could not evaluate expression '%s'\n", value);
-	      if (msg)
-		Swig_warning(WARN_PP_EVALUATION, Getfile(value), Getline(value), "Error: '%s'\n", msg);
-	      allow = 0;
-	    } else {
-	      if (val == 0)
-		allow = 0;
-	    }
-	  } else {
-	    Swig_error(Getfile(s), Getline(id), "Missing expression for #if.\n");
+	  val = Preprocessor_expr(sval, &e);
+	  if (e) {
+	    char *msg = Preprocessor_expr_error();
+	    Seek(value, 0, SEEK_SET);
+	    Swig_warning(WARN_PP_EVALUATION, Getfile(value), Getline(value), "Could not evaluate '%s'\n", value);
+	    if (msg)
+	      Swig_warning(WARN_PP_EVALUATION, Getfile(value), Getline(value), "Error: '%s'\n", msg);
 	    allow = 0;
+	  } else {
+	    if (val == 0)
+	      allow = 0;
 	  }
-	  expand_defined_operator = 0;
 	  mask = 1;
 	}
       } else if (Equal(id, kpp_elif)) {
@@ -1645,35 +1582,27 @@ String *Preprocessor_parse(String *s) {
 	    mask = 0;
 	  } else if (level == start_level) {
 	    int val;
-	    String *sval;
-	    expand_defined_operator = 1;
-	    sval = Preprocessor_replace(value);
+	    String *sval = Preprocessor_replace(value);
 	    Seek(sval, 0, SEEK_SET);
-	    if (Len(sval) > 0) {
-	      val = Preprocessor_expr(sval, &e);
-	      if (e) {
-		char *msg = Preprocessor_expr_error();
-		Seek(value, 0, SEEK_SET);
-		Swig_warning(WARN_PP_EVALUATION, Getfile(value), Getline(value), "Could not evaluate expression '%s'\n", value);
-		if (msg)
-		  Swig_warning(WARN_PP_EVALUATION, Getfile(value), Getline(value), "Error: '%s'\n", msg);
-		allow = 0;
-	      } else {
-		if (val)
-		  allow = 1 * mask;
-		else
-		  allow = 0;
-	      }
-	    } else {
-	      Swig_error(Getfile(s), Getline(id), "Missing expression for #elif.\n");
+	    val = Preprocessor_expr(sval, &e);
+	    if (e) {
+	      char *msg = Preprocessor_expr_error();
+	      Seek(value, 0, SEEK_SET);
+	      Swig_warning(WARN_PP_EVALUATION, Getfile(value), Getline(value), "Could not evaluate '%s'\n", value);
+	      if (msg)
+		Swig_warning(WARN_PP_EVALUATION, Getfile(value), Getline(value), "Error: '%s'\n", msg);
 	      allow = 0;
+	    } else {
+	      if (val)
+		allow = 1 * mask;
+	      else
+		allow = 0;
 	    }
-	    expand_defined_operator = 0;
 	  }
 	}
       } else if (Equal(id, kpp_warning)) {
 	if (allow) {
-	  Swig_warning(WARN_PP_CPP_WARNING, Getfile(s), Getline(id), "CPP #warning, \"%s\".\n", value);
+	  Swig_warning(WARN_PP_CPP_WARNING, Getfile(s), Getline(id), "CPP #warning, %s\n", value);
 	}
       } else if (Equal(id, kpp_error)) {
 	if (allow) {
@@ -1689,14 +1618,12 @@ String *Preprocessor_parse(String *s) {
 	  String *s1, *s2, *fn;
 	  char *dirname;
 	  int sysfile = 0;
-	  String *filename_processed;
 	  if (include_all && import_all) {
-	    Swig_warning(WARN_PP_INCLUDEALL_IMPORTALL, Getfile(s), Getline(id), "Both includeall and importall are defined: using includeall.\n");
+	    Swig_warning(WARN_PP_INCLUDEALL_IMPORTALL, Getfile(s), Getline(id), "Both includeall and importall are defined: using includeall\n");
 	    import_all = 0;
 	  }
-	  filename_processed = Preprocessor_replace(value);
-	  Seek(filename_processed, 0, SEEK_SET);
-	  fn = get_filename(filename_processed, &sysfile);
+	  Seek(value, 0, SEEK_SET);
+	  fn = get_filename(value, &sysfile);
 	  s1 = cpp_include(fn, sysfile);
 	  if (s1) {
 	    if (include_all)
@@ -1822,13 +1749,11 @@ String *Preprocessor_parse(String *s) {
 	Ungetc(c, s);
 	/* Look for common SWIG directives  */
 	if (Equal(decl, kpp_dinclude) || Equal(decl, kpp_dimport) || Equal(decl, kpp_dextern)) {
-	  /* Got some kind of file inclusion directive, eg: %import(option1="value1") "filename" */
+	  /* Got some kind of file inclusion directive  */
 	  if (allow) {
 	    DOH *s1, *s2, *fn, *opt;
-	    String *options_whitespace = NewStringEmpty();
-	    String *filename_whitespace = NewStringEmpty();
-	    String *filename_unprocessed = NewStringEmpty();
-	    String *filename_processed;
+	    String *options_whitespace = NewString("");
+	    String *filename_whitespace = NewString("");
 	    int sysfile = 0;
 
 	    if (Equal(decl, kpp_dextern)) {
@@ -1838,17 +1763,8 @@ String *Preprocessor_parse(String *s) {
 	    }
 	    skip_whitespace(s, options_whitespace);
 	    opt = get_options(s);
-
 	    skip_whitespace(s, filename_whitespace);
-	    copy_location(s, filename_unprocessed);
-	    while (((c = Getc(s)) != EOF) && (!isspace(c)))
-	      Putc(c, filename_unprocessed);
-	    if (isspace(c))
-	      Ungetc(c, s);
-	    filename_processed = Preprocessor_replace(filename_unprocessed);
-	    Seek(filename_processed, 0, SEEK_SET);
-
-	    fn = get_filename(filename_processed, &sysfile);
+	    fn = get_filename(s, &sysfile);
 	    s1 = cpp_include(fn, sysfile);
 	    if (s1) {
 	      char *dirname;
@@ -1878,8 +1794,6 @@ String *Preprocessor_parse(String *s) {
 	      Delete(s1);
 	    }
 	    Delete(fn);
-	    Delete(filename_processed);
-	    Delete(filename_unprocessed);
 	    Delete(filename_whitespace);
 	    Delete(options_whitespace);
 	  }
@@ -1964,7 +1878,6 @@ String *Preprocessor_parse(String *s) {
   if ((state >= 30) && (state < 40)) {
     Swig_error(Getfile(s), -1, "Unterminated comment starting on line %d\n", start_line);
   }
-
   copy_location(s, chunk);
   add_chunk(ns, chunk, allow);
 
