@@ -129,37 +129,37 @@ extern "C" {
   extern SwigType *SwigType_add_function(SwigType *t, ParmList *parms);
   extern SwigType *SwigType_add_template(SwigType *t, ParmList *parms);
   extern SwigType *SwigType_pop_function(SwigType *t);
-  extern ParmList *SwigType_function_parms(const SwigType *t, Node *file_line_node);
+  extern ParmList *SwigType_function_parms(SwigType *t, Node *file_line_node);
   extern List *SwigType_split(const SwigType *t);
   extern String *SwigType_pop(SwigType *t);
-  extern void SwigType_push(SwigType *t, String *s);
+  extern void SwigType_push(SwigType *t, SwigType *s);
   extern List *SwigType_parmlist(const SwigType *p);
-  extern String *SwigType_parm(const SwigType *p);
-  extern String *SwigType_str(const SwigType *s, const_String_or_char_ptr id);
-  extern String *SwigType_lstr(const SwigType *s, const_String_or_char_ptr id);
-  extern String *SwigType_rcaststr(const SwigType *s, const_String_or_char_ptr id);
-  extern String *SwigType_lcaststr(const SwigType *s, const_String_or_char_ptr id);
-  extern String *SwigType_manglestr(const SwigType *t);
-  extern SwigType *SwigType_ltype(const SwigType *t);
-  extern int SwigType_ispointer(const SwigType *t);
-  extern int SwigType_ispointer_return(const SwigType *t);
-  extern int SwigType_isfunctionpointer(const SwigType *t);
-  extern int SwigType_ismemberpointer(const SwigType *t);
-  extern int SwigType_isreference(const SwigType *t);
-  extern int SwigType_isreference_return(const SwigType *t);
-  extern int SwigType_isarray(const SwigType *t);
-  extern int SwigType_prefix_is_simple_1D_array(const SwigType *t);
-  extern int SwigType_isfunction(const SwigType *t);
-  extern int SwigType_isqualifier(const SwigType *t);
-  extern int SwigType_isconst(const SwigType *t);
-  extern int SwigType_issimple(const SwigType *t);
-  extern int SwigType_ismutable(const SwigType *t);
+  extern String *SwigType_parm(String *p);
+  extern String *SwigType_str(SwigType *s, const_String_or_char_ptr id);
+  extern String *SwigType_lstr(SwigType *s, const_String_or_char_ptr id);
+  extern String *SwigType_rcaststr(SwigType *s, const_String_or_char_ptr id);
+  extern String *SwigType_lcaststr(SwigType *s, const_String_or_char_ptr id);
+  extern String *SwigType_manglestr(SwigType *t);
+  extern SwigType *SwigType_ltype(SwigType *t);
+  extern int SwigType_ispointer(SwigType *t);
+  extern int SwigType_ispointer_return(SwigType *t);
+  extern int SwigType_isfunctionpointer(SwigType *t);
+  extern int SwigType_ismemberpointer(SwigType *t);
+  extern int SwigType_isreference(SwigType *t);
+  extern int SwigType_isreference_return(SwigType *t);
+  extern int SwigType_isarray(SwigType *t);
+  extern int SwigType_prefix_is_simple_1D_array(SwigType *t);
+  extern int SwigType_isfunction(SwigType *t);
+  extern int SwigType_isqualifier(SwigType *t);
+  extern int SwigType_isconst(SwigType *t);
+  extern int SwigType_issimple(SwigType *t);
+  extern int SwigType_ismutable(SwigType *t);
   extern int SwigType_isvarargs(const SwigType *t);
   extern int SwigType_istemplate(const SwigType *t);
-  extern int SwigType_isenum(const SwigType *t);
-  extern int SwigType_check_decl(const SwigType *t, const_String_or_char_ptr decl);
-  extern SwigType *SwigType_strip_qualifiers(const SwigType *t);
-  extern SwigType *SwigType_strip_single_qualifier(const SwigType *t);
+  extern int SwigType_isenum(SwigType *t);
+  extern int SwigType_check_decl(SwigType *t, const_String_or_char_ptr decl);
+  extern SwigType *SwigType_strip_qualifiers(SwigType *t);
+  extern SwigType *SwigType_strip_single_qualifier(SwigType *t);
   extern SwigType *SwigType_functionpointer_decompose(SwigType *t);
   extern String *SwigType_base(const SwigType *t);
   extern String *SwigType_namestr(const SwigType *t);
@@ -168,26 +168,27 @@ extern "C" {
   extern String *SwigType_istemplate_templateprefix(const SwigType *t);
   extern String *SwigType_templateargs(const SwigType *t);
   extern String *SwigType_prefix(const SwigType *t);
-  extern int SwigType_array_ndim(const SwigType *t);
-  extern String *SwigType_array_getdim(const SwigType *t, int n);
+  extern int SwigType_array_ndim(SwigType *t);
+  extern String *SwigType_array_getdim(SwigType *t, int n);
   extern void SwigType_array_setdim(SwigType *t, int n, const_String_or_char_ptr rep);
-  extern SwigType *SwigType_array_type(const SwigType *t);
-  extern SwigType *SwigType_default_create(const SwigType *ty);
-  extern SwigType *SwigType_default_deduce(const SwigType *t);
+  extern SwigType *SwigType_array_type(SwigType *t);
+  extern String *SwigType_default(SwigType *t);
+  extern SwigType *SwigType_default_create(SwigType *ty);
+  extern SwigType *SwigType_default_deduce(SwigType *t);
   extern void SwigType_typename_replace(SwigType *t, String *pat, String *rep);
   extern SwigType *SwigType_remove_global_scope_prefix(const SwigType *t);
-  extern SwigType *SwigType_alttype(const SwigType *t, int ltmap);
+  extern SwigType *SwigType_alttype(SwigType *t, int ltmap);
 
   extern void SwigType_template_defargs(Parm *parms, Parm *targs, Symtab *tscope, Symtab *tsdecl);
   extern SwigType *SwigType_template_deftype(const SwigType *type, Symtab *tscope);
 
 /* --- Type-system managment --- */
   extern void SwigType_typesystem_init(void);
-  extern int SwigType_typedef(const SwigType *type, const_String_or_char_ptr name);
+  extern int SwigType_typedef(SwigType *type, const_String_or_char_ptr name);
   extern int SwigType_typedef_class(const_String_or_char_ptr name);
   extern int SwigType_typedef_using(const_String_or_char_ptr qname);
   extern void SwigType_inherit(String *subclass, String *baseclass, String *cast, String *conversioncode);
-  extern int SwigType_issubtype(const SwigType *subtype, const SwigType *basetype);
+  extern int SwigType_issubtype(SwigType *subtype, SwigType *basetype);
   extern void SwigType_scope_alias(String *aliasname, Typetab *t);
   extern void SwigType_using_scope(Typetab *t);
   extern void SwigType_new_scope(const_String_or_char_ptr name);
@@ -196,17 +197,17 @@ extern "C" {
   extern Typetab *SwigType_set_scope(Typetab *h);
   extern void SwigType_print_scope(Typetab *t);
   extern SwigType *SwigType_typedef_resolve(const SwigType *t);
-  extern SwigType *SwigType_typedef_resolve_all(const SwigType *t);
-  extern SwigType *SwigType_typedef_qualified(const SwigType *t);
-  extern int SwigType_istypedef(const SwigType *t);
-  extern int SwigType_isclass(const SwigType *t);
+  extern SwigType *SwigType_typedef_resolve_all(SwigType *t);
+  extern SwigType *SwigType_typedef_qualified(SwigType *t);
+  extern int SwigType_istypedef(SwigType *t);
+  extern int SwigType_isclass(SwigType *t);
   extern void SwigType_attach_symtab(Symtab *syms);
-  extern void SwigType_remember(const SwigType *t);
-  extern void SwigType_remember_clientdata(const SwigType *t, const_String_or_char_ptr clientdata);
+  extern void SwigType_remember(SwigType *t);
+  extern void SwigType_remember_clientdata(SwigType *t, const_String_or_char_ptr clientdata);
   extern void SwigType_remember_mangleddata(String *mangled, const_String_or_char_ptr clientdata);
-  extern void (*SwigType_remember_trace(void (*tf) (const SwigType *, String *, String *))) (const SwigType *, String *, String *);
+  extern void (*SwigType_remember_trace(void (*tf) (SwigType *, String *, String *))) (SwigType *, String *, String *);
   extern void SwigType_emit_type_table(File *f_headers, File *f_table);
-  extern int SwigType_type(const SwigType *t);
+  extern int SwigType_type(SwigType *t);
 
 /* --- Symbol table module --- */
 
@@ -239,7 +240,7 @@ extern "C" {
   extern void Swig_symbol_inherit(Symtab *tab);
   extern SwigType *Swig_symbol_type_qualify(const SwigType *ty, Symtab *tab);
   extern String *Swig_symbol_string_qualify(String *s, Symtab *tab);
-  extern SwigType *Swig_symbol_typedef_reduce(const SwigType *ty, Symtab *tab);
+  extern SwigType *Swig_symbol_typedef_reduce(SwigType *ty, Symtab *tab);
 
   extern ParmList *Swig_symbol_template_defargs(Parm *parms, Parm *targs, Symtab *tscope, Symtab *tsdecl);
   extern SwigType *Swig_symbol_template_deftype(const SwigType *type, Symtab *tscope);
